@@ -1,6 +1,6 @@
 #' @docType package
 #' @name DatastreamDSWS2R
 #' @title DatastreamDSWS2R
-#' @description A package to manage access to the Refinitiv Datastream
+#' @description A package to manage access to the LSEG Datastream
 #'  DSWS webservice
-NULL
+"_PACKAGE"
