@@ -11,18 +11,19 @@
 #'
 #'
 #' @keywords internal
+#' @noRd
 #'
-.EncryptPassword <- function(strPassword=""){
+.EncryptPassword <- function(strPassword="") {
 
 
   iSeed <- as.raw(199L) # arbitrary number
   strCrypted <- ""
   bBytes <- charToRaw(strPassword)
 
-  for(b in bBytes)
+  for (b in bBytes)
   {
     iCryptedByte <- as.raw(xor(b , iSeed))
-    strCrypted <- paste0(strCrypted, formatC(as.integer(iCryptedByte),digits=3,width=3,flag="0"))
+    strCrypted <- paste0(strCrypted, formatC(as.integer(iCryptedByte),digits = 3,width = 3,flag = "0"))
     # add previous byte, XOR with arbitrary value
     iSeed <- xor(as.raw((as.integer(iSeed) + as.integer(iCryptedByte)) %% 255L), as.raw(67L))
   }
@@ -48,9 +49,10 @@
 #' @importFrom xts merge.xts .indexwday
 #' @importFrom stringr str_trim
 #' @keywords internal
+#' @noRd
 #'
-.getTimeseries <- function(Data, freq, digits, NA_VALUE){
-  if(ncol(Data) > 1) {
+.getTimeseries <- function(Data, freq, digits, NA_VALUE) {
+  if (ncol(Data) > 1) {
     # Make sure we are only dealing with a single column xts
     Data <- Data[,1]
   }
@@ -65,10 +67,10 @@
     # We need to make sure there are no blanks in the data
     startDate <- zoo::index(first(Data))
     endDate <- zoo::index(last(Data))
-    NADates <- seq(from=startDate, to=endDate, by="days")
-    NAData <- zoo(c(NA), order.by=NADates)
+    NADates <- seq(from = startDate, to = endDate, by = "days")
+    NAData <- zoo(c(NA), order.by = NADates)
     #merge and fill missing rows with NAs
-    wData <- xts::merge.xts(Data, NAData, fill=NA)
+    wData <- xts::merge.xts(Data, NAData, fill = NA)
 
     # This only picks the weeksdays from the original series
     wData <- wData[which(xts::.indexwday(wData) %in% 1:5),1]
@@ -78,16 +80,16 @@
     #assumption that they are in the right frequency
   }
 
-  sFormattedData <- suppressWarnings(formatC(wData, digits = digits, mode="double", format="f"))
+  sFormattedData <- suppressWarnings(formatC(wData, digits = digits, mode = "double", format = "f"))
   sFormattedData <- stringr::str_trim(sFormattedData)
 
   #We need to make sure that any missing data is replaced with the
   # the correct symbol
-  sFormattedData[which(sFormattedData=="NaN")] <- NA_VALUE
+  sFormattedData[which(sFormattedData == "NaN")] <- NA_VALUE
 
   #Collapse the array into a string
-  sData<-paste0(sFormattedData,collapse=",")
-  sData<-paste0(sData,",")
+  sData <- paste0(sFormattedData,collapse = ",")
+  sData <- paste0(sData,",")
 
   return(sData)
 }
@@ -148,79 +150,90 @@ UCTSUpload <- function(tsData,
                                             Sys.getenv("DatastreamPassword"),
                                             options()$Datastream.Password),
                        strServerName="https://product.datastream.com",
-                       strServerPage="/UCTS/UCTSMaint.asp"){
+                       strServerPage="/UCTS/UCTSMaint.asp") {
 
   #Check inputs are valid
 
-  if(!xtsible(tsData)){
+  if (!xtsible(tsData)) {
     stop(paste0("tsData must be a time-based object and not of class ",class(tsData)))
 
   }
 
-  if(!freq[1] %in% c("D","W","M","Q","Y")){
+  if (!freq[1] %in% c("D","W","M","Q","Y")) {
     stop("freq is not an allowed value")
   }
 
-  if(!ActPer[1] %in% c("N","Y")){
+  if (!ActPer[1] %in% c("N","Y")) {
     stop("ActPer is not an allowed value")
   }
 
-  if(!freqConversion[1] %in% c("ACT","SUM","AVG","END")){
+  if (!freqConversion[1] %in% c("ACT","SUM","AVG","END")) {
     stop("freqConversion is not an allowed value")
   }
 
-  if(!Alignment[1] %in% c("1ST","MID","END")){
+  if (!Alignment[1] %in% c("1ST","MID","END")) {
     stop("Alignment is not an allowed value")
   }
 
-  if(!Carry[1] %in% c("YES","NO","PAD")){
+  if (!Carry[1] %in% c("YES","NO","PAD")) {
     stop("Carry is not an allowed value")
   }
 
   # Limit decimals a number in range to the range 0-9
-  if(!is.numeric(Decimals)) Decimals <- 2L
+  if (!is.numeric(Decimals)) Decimals <- 2L
   Decimals <- as.integer(Decimals)
-  if(Decimals < 0) Decimals <- 0
-  if(Decimals > 9) Decimals <- 9
+  if (Decimals < 0) Decimals <- 0
+  if (Decimals > 9) Decimals <- 9
 
 
   # Trim any excess for units
   Units <- substr(Units,0,12)
 
   # Replace any ISO currency codes with DS codes
-  if(is.null(PrimeCurr)) {
+  if (is.null(PrimeCurr)) {
     PrimeCurr <- ""
   }
 
-  if(nchar(PrimeCurr) > 3){
+  if (nchar(PrimeCurr) > 3) {
     stop("Invalid currency.  Should be either 3 digit ISO code or Datastream code")
-  } else if(nchar(PrimeCurr) == 3 ){
+  } else if (nchar(PrimeCurr) == 3 ) {
     # Check ISO code is valid and convert to DS Code
     dfXRef <- DatastreamDSWS2R::currencyDS2ISO
-    if(PrimeCurr %in% dfXRef$isoCode){
+    if (PrimeCurr %in% dfXRef$isoCode) {
       PrimeCurr <- dfXRef$dsCode[which(PrimeCurr == dfXRef$isoCode &
                                          dfXRef$primeCode == TRUE)]
     } else {
       stop("Invalid currency.  Should be an ISO code in table currencyDS2ISO.")
     }
-  } else if(nchar(PrimeCurr) > 0 ){
+  } else if (nchar(PrimeCurr) > 0 ) {
     # Check DS Code is valid
-    PrimeCurr <- iconv(PrimeCurr, from="utf-8", to = "latin1")
+    PrimeCurr <- iconv(PrimeCurr, from = "utf-8", to = "latin1")
     dfXRef <- DatastreamDSWS2R::currencyDS2ISO
-    if(!PrimeCurr %in% dfXRef$dsCode){
+    if (!PrimeCurr %in% dfXRef$dsCode) {
       stop("Invalid currency.  Should be an Datastream code in table currencyDS2ISO.")
     }
   }
 
-
   # At the moment everything will be a full update, and a hard coded NA value
   NA_VALUE <- "NA"
 
+  # convert to xts object
+  myXtsData <- xts::as.xts(tsData)
+
+
+  # If we are using Daily data and the first day falls on a weekend then move that date to Friday
+
+  if (freq[1] == "D") {
+    startDay <- xts::.indexwday(myXtsData[1,])
+    if (startDay == 6) {
+      zoo::index(myXtsData)[1] <- zoo::index(myXtsData)[1] - 1
+    } else if (startDay == 0) {
+      zoo::index(myXtsData)[1] <- zoo::index(myXtsData)[1] - 2
+    }
+  }
 
   # Add Start Date for values - make sure it is in DD/MM/YY format
   #CMC actually the function returns a dd/MM/yyyy format post Y2K
-  # convert to xts object
-  myXtsData <- as.xts(tsData)
   startDate <- zoo::index(first(myXtsData))
   endDate <- zoo::index(last(myXtsData))
 
@@ -234,8 +247,8 @@ UCTSUpload <- function(tsData,
   dsParams <- list(CallType = "Upload",
                    TSMnemonic = toupper(TSCode),
                    TSMLM = toupper(MGMTGroup),
-                   TSStartDate = format(startDate,format="%d/%m/%Y"),
-                   TSEndDate = format(endDate,format="%d/%m/%Y"),
+                   TSStartDate = format(startDate,format = "%d/%m/%Y"),
+                   TSEndDate = format(endDate,format = "%d/%m/%Y"),
                    TSFrequency = freq[1],
                    TSTitle = seriesName,
                    TSUnits = Units,
@@ -249,11 +262,11 @@ UCTSUpload <- function(tsData,
                    ForceUpdateFlag1 = "Y",
                    ForceUpdateFlag2 = "Y",                   # We have ignored some logic in the original UCTS VBA code
                    #                   AmendFlag = "Y",
-                   TSValsStart = format(startDate,format="%d/%m/%Y"),  #TODO adjust this date according to the frequency of the data VBA function AdjustDateTo1st
+                   TSValsStart = format(startDate,format = "%d/%m/%Y"),  #TODO adjust this date according to the frequency of the data VBA function AdjustDateTo1st
                    NAValue = NA_VALUE,
                    TSValues = .getTimeseries(myXtsData,
-                                             freq= freq[1],
-                                             digits=Decimals,
+                                             freq = freq[1],
+                                             digits = Decimals,
                                              NA_VALUE),           #Now add the datapoints - the date element of the series is discarded here, with obvious risks
                    UserOption = .EncryptPassword(strPassword)
   )
@@ -266,7 +279,7 @@ UCTSUpload <- function(tsData,
   maxLoop <- 4
   retValue <- ""
 
-  while(nLoop < maxLoop){
+  while (nLoop < maxLoop) {
     retValue <- tryCatch(httr::POST(url = dsURL,
                                     body = dsParams,
                                     config =  httr::add_headers(encoding = "utf-8"),
@@ -275,11 +288,11 @@ UCTSUpload <- function(tsData,
                          error = function(e) e)
 
     # Break if an error or null
-    if(is.null(retValue)) break
-    if("error" %in% class(retValue)) break
+    if (is.null(retValue)) break
+    if (inherits(retValue, "error")) break
 
     # If did not get a time out then break
-    if(httr::status_code(retValue) != 408) break
+    if (httr::status_code(retValue) != 408) break
 
     # If not succesful then wait 2 seconds before re-submitting, ie give time for the
     # server/network to recover.
@@ -287,27 +300,27 @@ UCTSUpload <- function(tsData,
     nLoop <- nLoop + 1
   }
 
-  if(is.null(retValue)){
+  if (is.null(retValue)) {
     return(structure(FALSE,
                      error = "NULL value returned"))
   }
 
-  if("error" %in% class(retValue)){
+  if (inherits(retValue, "error")) {
     return(structure(FALSE,
                      error = paste("Error ", retValue$message)))
   }
 
 
 
-  if(httr::http_error(retValue)){
+  if (httr::http_error(retValue)) {
     return(structure(FALSE,
-                    error = paste("http Error: ", paste0(httr::http_status(retValue,
-                                                                          collapse = " : ")))))
+                    error = paste("http Error: ", paste0(httr::http_status(retValue),
+                                                                          collapse = " : "))))
   }
 
   myResponse <- content(retValue, as = "text")
 
-  if(myResponse[1] == "*OK*"){
+  if (myResponse[1] == "*OK*") {
     return(structure(TRUE,
                      error = ""))
   }
@@ -346,6 +359,8 @@ UCTSUpload <- function(tsData,
 #' @param Carry whether to carry data over missing dates
 #' @param PrimeCurr the currency of the timeseries
 #' @param overwrite if TRUE then existing data in the UCTS will be overwritten
+#' @param mydsws a dsws object that can be passed in.  Use this to avoid creating another dsws
+#' object in the same session.
 #' @param strUsername your Datastream username
 #' @param strPassword your Datastream Password
 #' @param strServerName URL of the Datastream server
@@ -370,6 +385,7 @@ UCTSAppend <- function(tsData,
                        Carry = c("YES","NO","PAD"),
                        PrimeCurr ="",
                        overwrite = TRUE,
+                       mydsws = dsws$new(),
                        strUsername = ifelse(Sys.getenv("DatastreamUsername") != "",
                                             Sys.getenv("DatastreamUsername"),
                                             options()$Datastream.Username),
@@ -377,26 +393,28 @@ UCTSAppend <- function(tsData,
                                             Sys.getenv("DatastreamPassword"),
                                             options()$Datastream.Password),
                        strServerName = "https://product.datastream.com",
-                       strServerPage = "/UCTS/UCTSMaint.asp"){
+                       strServerPage = "/UCTS/UCTSMaint.asp") {
 
   #Check inputs are valid - we can also rely on checks in UCTSUpload later
 
-  if(!xtsible(tsData)){
+  if (!xtsible(tsData)) {
     stop(paste0("tsData must be a time-based object and not of class ", class(tsData)))
   }
   tsData <- as.xts(tsData)
 
-  if(!freq[1] %in% c("D","W","M","Q","Y")){
+  if (!freq[1] %in% c("D","W","M","Q","Y")) {
     stop("freq is not an allowed value")
   }
 
   # Get the existing UCTS from Datastream
-  mydsws <- dsws$new()
+  if (is.null(mydsws)) {
+    mydsws <- dsws$new()
+  }
   tsExisting <- mydsws$timeSeriesRequest(instrument = TSCode,
                                          startDate = as.Date("1950-01-01"),
                                          endDate = index(last(tsData)),
                                          frequency = freq)
-  if(is.null(tsExisting)){
+  if (is.null(tsExisting)) {
     errMsg <- paste0("Datastream Server Error retrieving existing series\n",
                      paste(mydsws$errorlist, collapse = "\n", sep = "\n"))
     stop(errMsg)
@@ -411,7 +429,7 @@ UCTSAppend <- function(tsData,
 
   # Check if any data was found
 
-  if(length(validRows) != 0){
+  if (length(validRows) != 0) {
     # There was no existing timeseries
     # Take the non-null middle segment
 
@@ -422,7 +440,7 @@ UCTSAppend <- function(tsData,
 
     # Combine the new data with the existing data
 
-    if(overwrite){
+    if (overwrite) {
       # append with new data overwriting the old
       tsData <- xts::make.index.unique(rbind(tsData, tsExisting), drop = TRUE)
 
